@@ -1,5 +1,5 @@
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -29,7 +29,50 @@ from .charsets import MYSQL_CHARACTER_SETS
 
 MAX_PACKET_LENGTH = 16777215
 NET_BUFFER_LENGTH = 8192
+MAX_MYSQL_TABLE_COLUMNS = 4096
 
+DEFAULT_CONFIGURATION = {
+    'database': None,
+    'user': '',
+    'password': '',
+    'host': '127.0.0.1',
+    'port': 3306,
+    'unix_socket': None,
+    'use_unicode': True,
+    'charset': 'utf8',
+    'collation': None,
+    'converter_class': None,
+    'autocommit': False,
+    'time_zone': None,
+    'sql_mode': None,
+    'get_warnings': False,
+    'raise_on_warnings': False,
+    'connection_timeout': None,
+    'client_flags': 0,
+    'compress': False,
+    'buffered': False,
+    'raw': False,
+    'ssl_ca': None,
+    'ssl_cert': None,
+    'ssl_key': None,
+    'ssl_verify_cert': False,
+    'ssl_cipher': None,
+    'passwd': None,
+    'db': None,
+    'connect_timeout': None,
+    'dsn': None,
+    'force_ipv6': False,
+    'auth_plugin': None,
+    'allow_local_infile': True,
+    'consume_results': False,
+}
+
+CNX_POOL_ARGS = ('pool_name', 'pool_size', 'pool_reset_session')
+CNX_FABRIC_ARGS = ['fabric_host', 'fabric_username', 'fabric_password',
+                   'fabric_port', 'fabric_connect_attempts',
+                   'fabric_connect_delay', 'fabric_report_errors',
+                   'fabric_ssl_ca', 'fabric_ssl_key', 'fabric_ssl_cert',
+                   'fabric_user']
 
 def flag_is_set(flag, flags):
     """Checks if the flag is set
@@ -355,6 +398,8 @@ class ClientFlag(_Flags):
     CONNECT_ARGS = 1 << 20
     PLUGIN_AUTH_LENENC_CLIENT_DATA = 1 << 21
     CAN_HANDLE_EXPIRED_PASSWORDS = 1 << 22
+    SESION_TRACK = 1 << 23
+    DEPRECATE_EOF = 1 << 24
     SSL_VERIFY_SERVER_CERT = 1 << 30
     REMEMBER_OPTIONS = 1 << 31
 
@@ -377,6 +422,14 @@ class ClientFlag(_Flags):
         'SECURE_CONNECTION': (1 << 15, 'New 4.1 authentication'),
         'MULTI_STATEMENTS': (1 << 16, 'Enable/disable multi-stmt support'),
         'MULTI_RESULTS': (1 << 17, 'Enable/disable multi-results'),
+        'PS_MULTI_RESULTS': (1 << 18, 'Multi-results in PS-protocol'),
+        'PLUGIN_AUTH': (1 << 19, 'Client supports plugin authentication'),
+        'CONNECT_ARGS': (1 << 20, 'Client supports connection attributes'),
+        'PLUGIN_AUTH_LENENC_CLIENT_DATA': (1 << 21,
+                                           'Enable authentication response packet to be larger than 255 bytes'),
+        'CAN_HANDLE_EXPIRED_PASSWORDS': (1 << 22, "Don't close the connection for a connection with expired password"),
+        'SESION_TRACK': (1 << 23, 'Capable of handling server state change information'),
+        'DEPRECATE_EOF': (1 << 24, 'Client no longer needs EOF packet'),
         'SSL_VERIFY_SERVER_CERT': (1 << 30, ''),
         'REMEMBER_OPTIONS': (1 << 31, ''),
     }
@@ -468,14 +521,14 @@ class ShutdownType(_Constants):
     Shutdown types used by the COM_SHUTDOWN server command.
     """
     _prefix = ''
-    SHUTDOWN_DEFAULT = b'\x00'
-    SHUTDOWN_WAIT_CONNECTIONS = b'\x01'
-    SHUTDOWN_WAIT_TRANSACTIONS = b'\x02'
-    SHUTDOWN_WAIT_UPDATES = b'\x08'
-    SHUTDOWN_WAIT_ALL_BUFFERS = b'\x10'
-    SHUTDOWN_WAIT_CRITICAL_BUFFERS = b'\x11'
-    KILL_QUERY = b'\xfe'
-    KILL_CONNECTION = b'\xff'
+    SHUTDOWN_DEFAULT = 0
+    SHUTDOWN_WAIT_CONNECTIONS = 1
+    SHUTDOWN_WAIT_TRANSACTIONS = 2
+    SHUTDOWN_WAIT_UPDATES = 8
+    SHUTDOWN_WAIT_ALL_BUFFERS = 16
+    SHUTDOWN_WAIT_CRITICAL_BUFFERS = 17
+    KILL_QUERY = 254
+    KILL_CONNECTION = 255
 
     desc = {
         'SHUTDOWN_DEFAULT': (
@@ -633,7 +686,7 @@ class CharacterSet(_Constants):
         return tuple(res)
 
 
-class SQLMode(_Constants):  # pylint: disable=R0921
+class SQLMode(_Constants):
     """MySQL SQL Modes
 
     The numeric values of SQL Modes are not interesting, only the names
