@@ -1,5 +1,5 @@
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2013, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2013, 2016, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -431,10 +431,13 @@ def foreach_cnx(*cnx_classes, **extra_config):
                     self.cnx = cnx_class(**self.config)
                     self._testMethodName = "{0} (using {1})".format(
                         func.__name__, cnx_class.__name__)
-                except:
+                except Exception as exc:
                     if hasattr(self, 'cnx'):
                         # We will rollback/close later
                         pass
+                    else:
+                        traceback.print_exc(file=sys.stdout)
+                        raise exc
                 try:
                     func(self, *args, **kwargs)
                 except Exception as exc:
@@ -456,6 +459,7 @@ class MySQLConnectorTests(unittest.TestCase):
     def __init__(self, methodName='runTest'):
         from mysql.connector import connection
         self.all_cnx_classes = [connection.MySQLConnection]
+        self.maxDiff = 64
         try:
             import _mysql_connector
             from mysql.connector import connection_cext
@@ -775,7 +779,7 @@ def install_connector(root_dir, install_dir, connc_location=None):
     ])
 
     if connc_location:
-        cmd.extend(['--with-mysql-capi', connc_location])
+        cmd.extend(['--static', '--with-mysql-capi', connc_location])
 
     prc = subprocess.Popen(cmd, stdin=subprocess.PIPE,
                            stderr=subprocess.STDOUT, stdout=subprocess.PIPE,
