@@ -1,5 +1,5 @@
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -25,37 +25,49 @@
 """
 
 import datetime
+import unittest
 import sys
 import unittest
 
 import tests
 
 # Load 3rd party _after_ loading tests
-from django.conf import settings
+try:
+    from django.conf import settings
+except ImportError:
+    DJANGO_AVAILABLE = False
+else:
+    DJANGO_AVAILABLE = True
 
 # Have to setup Django before loading anything else
-settings.configure()
-DBCONFIG = tests.get_mysql_config()
+if DJANGO_AVAILABLE:
+    try:
+        settings.configure()
+    except RuntimeError as exc:
+        if not 'already configured' in str(exc):
+            raise
+    DBCONFIG = tests.get_mysql_config()
 
-settings.DATABASES = {
-    'default': {
-        'ENGINE': 'mysql.connector.django',
-        'NAME': DBCONFIG['database'],
-        'USER': 'root',
-        'PASSWORD': '',
-        'HOST': DBCONFIG['host'],
-        'PORT': DBCONFIG['port'],
-        'TEST_CHARSET': 'utf8',
-        'TEST_COLLATION': 'utf8_general_ci',
-        'CONN_MAX_AGE': 0,
-        'AUTOCOMMIT': True,
-    },
-}
-settings.SECRET_KEY = "django_tests_secret_key"
-settings.TIME_ZONE = 'UTC'
-settings.USE_TZ = False
-settings.SOUTH_TESTS_MIGRATE = False
-settings.DEBUG = False
+    settings.DATABASES = {
+        'default': {
+            'ENGINE': 'mysql.connector.django',
+            'NAME': DBCONFIG['database'],
+            'USER': 'root',
+            'PASSWORD': '',
+            'HOST': DBCONFIG['host'],
+            'PORT': DBCONFIG['port'],
+            'TEST_CHARSET': 'utf8',
+            'TEST_COLLATION': 'utf8_general_ci',
+            'CONN_MAX_AGE': 0,
+            'AUTOCOMMIT': True,
+            'TIME_ZONE': None,
+        },
+    }
+    settings.SECRET_KEY = "django_tests_secret_key"
+    settings.TIME_ZONE = 'UTC'
+    settings.USE_TZ = False
+    settings.SOUTH_TESTS_MIGRATE = False
+    settings.DEBUG = False
 
 TABLES = {}
 TABLES['django_t1'] = """
@@ -81,17 +93,19 @@ FOREIGN KEY (id_t1) REFERENCES django_t1(id) ON DELETE CASCADE
 
 # Have to load django.db to make importing db backend work for Django < 1.6
 import django.db  # pylint: disable=W0611
-if tests.DJANGO_VERSION >= (1, 6):
-    from django.db.backends import FieldInfo
 from django.db.backends.signals import connection_created
 from django.utils.safestring import SafeBytes, SafeText
 
 import mysql.connector
-from mysql.connector.django.base import (DatabaseWrapper, DatabaseOperations,
-                                         DjangoMySQLConverter)
-from mysql.connector.django.introspection import DatabaseIntrospection
+from mysql.connector.django.introspection import FieldInfo
+
+if DJANGO_AVAILABLE:
+    from mysql.connector.django.base import (
+        DatabaseWrapper, DatabaseOperations, DjangoMySQLConverter)
+    from mysql.connector.django.introspection import DatabaseIntrospection
 
 
+@unittest.skipIf(not DJANGO_AVAILABLE, "Django not available")
 class DjangoIntrospection(tests.MySQLConnectorTests):
 
     """Test the Django introspection module"""
@@ -130,14 +144,14 @@ class DjangoIntrospection(tests.MySQLConnectorTests):
 
     def test_get_table_list(self):
         cur = self.cnx.cursor()
-        exp = list(TABLES.keys())
-        for exp in list(TABLES.keys()):
+        for exp in TABLES.keys():
             if sys.version_info < (2, 7):
                 self.assertTrue(exp in self.introspect.get_table_list(cur))
             else:
-                self.assertIn(exp, self.introspect.get_table_list(cur),
-                              "Table {table_name} not in table list".format(
-                                  table_name=exp))
+                res = any(table.name == exp
+                          for table in self.introspect.get_table_list(cur))
+                self.assertTrue(res, "Table {table_name} not in table list"
+                                     "".format(table_name=exp))
 
     def test_get_table_description(self):
         cur = self.cnx.cursor()
@@ -148,24 +162,39 @@ class DjangoIntrospection(tests.MySQLConnectorTests):
                 ('c1', 3, None, None, None, None, 1, 16392),
                 ('c2', 253, None, 20, None, None, 1, 16388)
             ]
-        else:
+        elif tests.DJANGO_VERSION < (1, 8):
             exp = [
-                FieldInfo(name='id', type_code=3, display_size=None,
+                FieldInfo(name=u'id', type_code=3, display_size=None,
                           internal_size=None, precision=None, scale=None,
                           null_ok=0),
-                FieldInfo(name='c1', type_code=3, display_size=None,
+                FieldInfo(name=u'c1', type_code=3, display_size=None,
                           internal_size=None, precision=None, scale=None,
                           null_ok=1),
-                FieldInfo(name='c2', type_code=253, display_size=None,
+                FieldInfo(name=u'c2', type_code=253, display_size=None,
                           internal_size=20, precision=None, scale=None,
                           null_ok=1)
             ]
+        else:
+            exp = [
+                FieldInfo(name=u'id', type_code=3, display_size=None,
+                          internal_size=None, precision=10, scale=None,
+                          null_ok=0, extra=u'auto_increment'),
+                FieldInfo(name=u'c1', type_code=3, display_size=None,
+                          internal_size=None, precision=10, scale=None,
+                          null_ok=1, extra=u''),
+                FieldInfo(name=u'c2', type_code=253, display_size=None,
+                          internal_size=20, precision=None, scale=None,
+                          null_ok=1, extra=u'')
+            ]
         res = self.introspect.get_table_description(cur, 'django_t1')
         self.assertEqual(exp, res)
 
     def test_get_relations(self):
         cur = self.cnx.cursor()
-        exp = {1: (0, 'django_t1')}
+        if tests.DJANGO_VERSION < (1, 8):
+            exp = {1: (0, 'django_t1')}
+        else:
+            exp = {u'id_t1': (u'id', u'django_t1')}
         self.assertEqual(exp, self.introspect.get_relations(cur, 'django_t2'))
 
     def test_get_key_columns(self):
@@ -187,7 +216,32 @@ class DjangoIntrospection(tests.MySQLConnectorTests):
         res = self.introspect.get_primary_key_column(cur, 'django_t1')
         self.assertEqual('id', res)
 
+    def test_get_constraints(self):
+        cur = self.cnx.cursor()
+        exp = {
+            'PRIMARY': {'check': False,
+                        'columns': ['id'],
+                        'foreign_key': None,
+                        'index': True,
+                        'primary_key': True,
+                        'unique': True},
+            'django_t2_ibfk_1': {'check': False,
+                                 'columns': ['id_t1'],
+                                 'foreign_key': ('django_t1', 'id'),
+                                 'index': False,
+                                 'primary_key': False,
+                                 'unique': False},
+            'id_t1': {'check': False,
+                      'columns': ['id_t1'],
+                      'foreign_key': None,
+                      'index': True,
+                      'primary_key': False,
+                      'unique': False}
+        }
+        self.assertEqual(
+            exp, self.introspect.get_constraints(cur, 'django_t2'))
 
+@unittest.skipIf(not DJANGO_AVAILABLE, "Django not available")
 class DjangoDatabaseWrapper(tests.MySQLConnectorTests):
 
     """Test the Django base.DatabaseWrapper class"""
@@ -210,6 +264,8 @@ class DjangoDatabaseWrapper(tests.MySQLConnectorTests):
         exp = self.conn.converter._time_to_mysql(value)
         self.assertEqual(exp, self.cnx.ops.value_to_db_time(value))
 
+
+
     def test_signal(self):
         from django.db import connection
 
@@ -257,26 +313,49 @@ class DjangoDatabaseOperations(tests.MySQLConnectorTests):
         self.dbo = DatabaseOperations(self.cnx)
 
     def test_value_to_db_time(self):
-        self.assertEqual(None, self.dbo.value_to_db_time(None))
+        if tests.DJANGO_VERSION < (1, 9):
+            value_to_db_time = self.dbo.value_to_db_time
+        else:
+            value_to_db_time = self.dbo.adapt_timefield_value
+
+        self.assertEqual(None, value_to_db_time(None))
 
         value = datetime.time(0, 0, 0)
         exp = self.conn.converter._time_to_mysql(value)
-        self.assertEqual(exp, self.dbo.value_to_db_time(value))
+        self.assertEqual(exp, value_to_db_time(value))
 
         value = datetime.time(2, 5, 7)
         exp = self.conn.converter._time_to_mysql(value)
-        self.assertEqual(exp, self.dbo.value_to_db_time(value))
+        self.assertEqual(exp, value_to_db_time(value))
 
     def test_value_to_db_datetime(self):
-        self.assertEqual(None, self.dbo.value_to_db_datetime(None))
+        if tests.DJANGO_VERSION < (1, 9):
+            value_to_db_datetime = self.dbo.value_to_db_datetime
+        else:
+            value_to_db_datetime = self.dbo.adapt_datetimefield_value
+
+        self.assertEqual(None, value_to_db_datetime(None))
 
         value = datetime.datetime(1, 1, 1)
         exp = self.conn.converter._datetime_to_mysql(value)
-        self.assertEqual(exp, self.dbo.value_to_db_datetime(value))
+        self.assertEqual(exp, value_to_db_datetime(value))
 
         value = datetime.datetime(2, 5, 7, 10, 10)
         exp = self.conn.converter._datetime_to_mysql(value)
-        self.assertEqual(exp, self.dbo.value_to_db_datetime(value))
+        self.assertEqual(exp, value_to_db_datetime(value))
+
+    def test_bulk_insert_sql(self):
+        num_values = 5
+        fields = ["col1", "col2", "col3"]
+        placeholder_rows = [["%s"] * len(fields) for _ in range(num_values)]
+        exp = "VALUES {0}".format(", ".join(
+            ["({0})".format(", ".join(["%s"] * len(fields)))] * num_values))
+        if tests.DJANGO_VERSION < (1, 9):
+            self.assertEqual(
+                exp, self.dbo.bulk_insert_sql(fields, num_values))
+        else:
+            self.assertEqual(
+                exp, self.dbo.bulk_insert_sql(fields, placeholder_rows))
 
 
 class DjangoMySQLConverterTests(tests.MySQLConnectorTests):
