@@ -1,5 +1,5 @@
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -25,11 +25,10 @@
 """
 
 import sys
-import os
 import tests
 import imp
 
-import version
+import setupinfo
 
 
 class VersionTests(tests.MySQLConnectorTests):
@@ -38,7 +37,7 @@ class VersionTests(tests.MySQLConnectorTests):
 
     def test_version(self):
         """Test validity of version"""
-        vs = version.VERSION
+        vs = setupinfo.VERSION
         self.assertTrue(all(
             [isinstance(vs[0], int),
              isinstance(vs[1], int),
@@ -53,58 +52,57 @@ class VersionTests(tests.MySQLConnectorTests):
         self.assertTrue(hasattr(mysql.connector, '__version_info__'))
         self.assertTrue(isinstance(mysql.connector.__version__, str))
         self.assertTrue(isinstance(mysql.connector.__version_info__, tuple))
-        self.assertEqual(version.VERSION_TEXT, mysql.connector.__version__)
-        self.assertEqual(version.VERSION, mysql.connector.__version_info__)
+        self.assertEqual(setupinfo.VERSION_TEXT, mysql.connector.__version__)
+        self.assertEqual(setupinfo.VERSION, mysql.connector.__version_info__)
 
 
-class MetaSetupInfoTests(tests.MySQLConnectorTests):
+class SetupInfoTests(tests.MySQLConnectorTests):
 
     """Testing meta setup information
 
-    We are importing the metasetupinfo module insite the unit tests
+    We are importing the setupinfo module insite the unit tests
     to be able to actually do tests.
     """
 
+    def setUp(self):
+        # we temper with version_info, play safe, keep copy
+        self._sys_version_info = sys.version_info
+
+    def tearDown(self):
+        # we temper with version_info, play safe, restore copy
+        sys.version_info = self._sys_version_info
+
     def test_name(self):
         """Test the name of Connector/Python"""
-        import metasetupinfo
-        self.assertEqual('mysql-connector-python', metasetupinfo.name)
+        import setupinfo
+        self.assertEqual('mysql-connector-python', setupinfo.name)
 
     def test_dev_statuses(self):
         """Test the development statuses"""
-        import metasetupinfo
+        import setupinfo
         exp = {
             'a': '3 - Alpha',
             'b': '4 - Beta',
             'rc': '4 - Beta',
             '': '5 - Production/Stable'
         }
-        self.assertEqual(exp, metasetupinfo.DEVELOPMENT_STATUSES)
-
-    def test_sys_path(self):
-        """Test if sys.path has been updated"""
-        # Following import is not used, but it does set the sys.path
-        import metasetupinfo
-        exp = 'python' + str(sys.version_info[0]) + '/'
-        self.assertEqual(exp, sys.path[0])
+        self.assertEqual(exp, setupinfo.DEVELOPMENT_STATUSES)
 
     def test_package_dir(self):
         """Test the package directory"""
-        import metasetupinfo
+        import setupinfo
         exp = {
-            '': 'python' + str(sys.version_info[0]),
-            'mysql.connector.django': os.path.join('python23', 'django'),
-            'mysql.connector.fabric': os.path.join('python23', 'fabric'),
+            '': 'lib',
         }
-        self.assertEqual(exp, metasetupinfo.package_dir)
+        self.assertEqual(exp, setupinfo.package_dir)
 
     def test_unsupported_python(self):
         """Test if old Python version are unsupported"""
-        import metasetupinfo
+        import setupinfo
         tmp = sys.version_info
         sys.version_info = (3, 0, 0, 'final', 0)
         try:
-            imp.reload(metasetupinfo)
+            imp.reload(setupinfo)
         except RuntimeError:
             pass
         else:
@@ -113,31 +111,32 @@ class MetaSetupInfoTests(tests.MySQLConnectorTests):
 
     def test_version(self):
         """Test the imported version information"""
-        import metasetupinfo
-        ver = metasetupinfo.VERSION
+        import setupinfo
+        ver = setupinfo.VERSION
         exp = '{0}.{1}.{2}'.format(*ver[0:3])
-        self.assertEqual(exp, metasetupinfo.version)
+        self.assertEqual(exp, setupinfo.version)
 
     def test_misc_meta(self):
         """Test miscellaneous data such as URLs"""
-        import metasetupinfo
+        import setupinfo
         self.assertEqual(
             'http://dev.mysql.com/doc/connector-python/en/index.html',
-            metasetupinfo.url)
+            setupinfo.url)
         self.assertEqual(
             'http://dev.mysql.com/downloads/connector/python/',
-            metasetupinfo.download_url)
+            setupinfo.download_url)
 
     def test_classifiers(self):
         """Test Trove classifiers"""
-        import metasetupinfo
-        for clsfr in metasetupinfo.classifiers:
+        import setupinfo
+        for clsfr in setupinfo.classifiers:
             if 'Programming Language :: Python' in clsfr:
                 ver = clsfr.replace('Programming Language :: Python :: ', '')
-                if ver not in ('2.6', '2.7', '3', '3.1', '3.2', '3.3'):
+                if ver not in ('2.6', '2.7', '3', '3.1', '3.2', '3.3', '3.4',
+                               '3.5'):
                     self.fail('Unsupported version in classifiers')
             if 'Development Status ::' in clsfr:
                 status = clsfr.replace('Development Status :: ', '')
                 self.assertEqual(
-                    metasetupinfo.DEVELOPMENT_STATUSES[version.VERSION[3]],
+                    setupinfo.DEVELOPMENT_STATUSES[setupinfo.VERSION[3]],
                     status)
